
# Slot: rules


the collection of rules that apply to all members of this class

URI: [linkml:class_definition_rules](https://w3id.org/linkml/class_definition_rules)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..\*</sub> [ClassRule](ClassRule.md)

## Parents

 *  is_a: [rules](rules.md)

## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | sh:rule |

